@@ -3,7 +3,6 @@
 
 #include <QObject>
 
-#include <MauiKit/Core/fmh.h>
 #include <MauiKit/Core/mauilist.h>
 
 #define CINEMA_QUERY_MAX_LIMIT 20000
@@ -27,7 +26,6 @@ class VideosModel : public MauiList
 
 public:
     explicit VideosModel(QObject *parent = nullptr);
-    ~VideosModel();
 
     const FMH::MODEL_LIST &items() const override final;
 
